<?php
$lang['address'] = 'Adresa';
$lang['add_category'] = 'Pridať kateg&oacute;riu';
$lang['add_icon'] = 'Pridať ikonku';
$lang['add_map'] = 'Pridať mapu';
$lang['add_map_point'] = 'Pridať bod na mape';
$lang['add_point_for_map'] = 'Pridať bod na mape &quot;%s&quot;';
$lang['aerial'] = 'Leteck&aacute; mapa';
$lang['anchor_x'] = 'Kotva X Pixel umiestnenie';
$lang['anchor_y'] = 'Kotva Y Pixel umiestnenie';
$lang['apply'] = 'Vykonať';
$lang['ask_delete_icon'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť ikonku zo zoznamu (obr&aacute;zok fyzicky nebude zmazan&yacute;)? ';
$lang['ask_reset_icons'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť v&scaron;etky ikonky a vr&aacute;tiť stav do prednastaven&yacute;ch nastaven&iacute;? ';
$lang['baloon_maptemplate'] = '&Scaron;abl&oacute;na bulbiy';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['category_template'] = '&Scaron;abl&oacute;n zobrazenia kateg&oacute;rie';
$lang['center_lat'] = 'Latitude pre vycentrovanie';
$lang['center_lon'] = 'Longitude pre vycentrovanie';
$lang['click'] = 'Kliknutie';
$lang['combine_points'] = 'Kombinovať jednotliv&eacute; značky, ktor&eacute; su v rozshau';
$lang['combined_points_icon'] = 'Ikona pužit&aacute; pre kombinovan&eacute; body';
$lang['controls'] = 'Navig&aacute;cia';
$lang['controls_size'] = 'Veľkosť navig&aacute;cie';
$lang['default'] = 'Prednastaven&eacute;';
$lang['default_icon'] = 'Prednastavenn&aacute; ikonka';
$lang['default_templates'] = 'Prednastaven&eacute; &scaron;abl&oacute;ny';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['delete_icon'] = 'Odstr&aacute;niť ikonku';
$lang['delete_map'] = 'Odstr&aacute;niť mapu';
$lang['delete_map_point'] = 'Odstr&aacute;niť bod z mapy';
$lang['description'] = 'Popis';
$lang['directions'] = 'Uk&aacute;zať trasy';
$lang['directions_dest'] = 'Kde bud&uacute; vykreslen&eacute; s&uacute;radnice';
$lang['directions_units'] = 'Jednotky s&uacute;radnic';
$lang['dirform_maptemplate'] = '&Scaron;ablona s&uacute;radnic';
$lang['dropdown'] = 'V&yacute;berov&eacute; pole';
$lang['edit'] = 'Upraviť';
$lang['edit_category'] = 'Upraviť značkovacie kateg&oacute;rie';
$lang['edit_icon'] = 'Upraviť ikonku';
$lang['edit_map'] = 'Upraviť mapu';
$lang['edit_map_point'] = 'Upraviť bod na mape';
$lang['edit_map_points'] = 'Upraviť body na mapet';
$lang['edit_points_for_map'] = 'Upraviť body na mape &quot;%s&quot;';
$lang['error_browser_incompatible'] = 'Prehliadač nepodporuje zobrazovanie map z google';
$lang['error_cannotdelete'] = 'T&aacute;to položka nem&ocirc;že byť odstr&aacute;nen&aacute;';
$lang['error_deletecategory'] = 'Probl&eacute;m s odst&aacute;nen&iacute;m kateg&oacute;rie ';
$lang['error_invalidparams'] = 'Jeden z povinn&yacute;h parametrov ch&yacute;ba';
$lang['error_mapelem_notfound'] = 'Časť mapy nen&aacute;jden&aacute;';
$lang['error_nameexists'] = 'Položka s t&yacute;mto n&aacute;zvom už existuje';
$lang['error_noapikey'] = 'Google API Key je pr&aacute;zdne';
$lang['error_noapikey2'] = 'Tento modul vyžaduje Google Api kľuč, bez tohto kľuča bude nefunkčn&yacute;';
$lang['error_notfound'] = 'Požadovan&aacute; položka nen&aacute;jden&aacute;';
$lang['error_permissiondenied'] = 'Nem&aacute;te dostatočn&eacute; pr&aacute;va na vykonanie tejto akcie';
$lang['friendlyname'] = 'Google mapy';
$lang['from'] = 'Z';
$lang['get_directions'] = 'Z&iacute;skať s&uacute;radnice';
$lang['google_api_key'] = 'Google API kľ&uacute;č';
$lang['help'] = '<h3>What does this do</h3>
  <p>This module provides a quick, convenient, yet flexible and extendable way to place google maps on a page providing a number of built in functions, and providing easy extendability for those familiar with Javascript and the Google Maps API&#039;;
<h3>Features:</h3>
<ul>
  <li>Static map creation using a full admin interface for managing maps and markers within a map.</li>
  <li>Flexible marker icon management.</li>
  <li>The ability to categorize markers.  Markers can belong to more than one category.</li>
  <li>Infowindow content can be specified using HTML</li>
  <li>Streetview support</li>
  <li>The ability to display a sidebar of all markers associated with a map.</li>
  <li>The ability to display a category panel, and hide icons by unchecking a category checkbox.</li>
  <li>Directions support (either by displaying the route in the map (and with directions in a seperate panel), or by opening a new window</li>
  <li>Reads sensor information from GPS sensors on mobile devices.</li>
  <li>The ability to group markers that are within a lat/long radius to a single marker with a special icon.</li>
  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
  <li>Uses jquery for advanced DOM manipulation.</li>
</ul>
<h3>How Do I Use It?</h3>
<ul>
<li>Install the module via the normal methods</li>
<li>Setup your users and groups with the appropriate permissions:
  <ul>
    <li>The &#039;Manage Maps&#039; Permission allows administrators to add/edit and delete maps</li>
    <li>The &#039;Manage Map Locations&#039; permission allows administrators to add/edit/delete points within a map</li>
  </ul>
</li>
<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking.  Note that when resetting one of the map templates to defaults, you must still press the &amp;quot;Apply&amp;quot; or &amp;quot;Apply&amp;quot; buttons.</p>
<li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
<li>Create one or more points within the map, either by specifying a latitude and longitude, or with an address.</li>
<li>Add the {CGGoogleMaps} tag inside the content block of a page, or inside a page template.  Then you&#039;re finished.</li>
</ul>
<br/>
<h3>Adding Points to a Map Dynamically</h3>
<p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
<h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
<p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
<h4>Usage:</h4>
<pre><code>{cggm_add_dynpoint map=1 name=&#039;New York&#039; address=&#039;New York, NY&#039; icon=&#039;food&#039;}</code></pre><br/>
<h4>Parameters:</h4>
  <ul> 
<li><strong>required</strong> - map : The (integer) ID of the map to add the point to</li>
<li><strong>required</strong> - name : The name of the point to add</li>
<li><em>optional</em> - desc/description : The HTML content to show in the info window</li>
<li><em>optional</em> - address : The address of the location you are adding. (you must specify an address, or lat and long parameters)</li>
<li><em>optional</em> - lat : The latitude of the location you are adding.</li>
<li><em>optional</em> - long : The longitude of the location you are adding.</li>
<li><em>optional</em> - category : A comma separated list of categories for this point (there is no need for the categories to already exists)</li>
<li><em>optional</em> - tooltip : A tooltip to display when hovering over a point.</li>
<li><em>optional</em> - icon : The name of an icon to use for this point.</li>
  </ul>
<br/>
<p><strong>Note:</strong> Either the lat and long parameters must be specified, or the address.</p>
<p><strong>Note:</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
</ul>
<h3>Upgrade Information:</h3>
<p><strong>Note:</strong> For people upgrading from CGGoogleMaps 1.x to the new 2.x series some work may need to be done, particularly if you have changed your map template, or are using custom options.  You may need to revise the styling of your map templates, and then update/save the values in the map settings.</p>
<p>Also: The sidebar_html, and sidebar_class parameters have been removed from the {cggm_add_dynpoint} smarty plugin.  This is due to the category functionality that has been added.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Requirements</h3>
<p>This map functionality makes extensive use of <strong>JQuery</strong> it is your responsibility to include jquery in pages that use these maps and ensure that it is loaded before the map is called.  The easiest way to do this is by installing the JQueryTools module and adding {JQueryTools action=incjs} into the head portion of your page template.</p>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['height'] = 'V&yacute;&scaron;ka';
$lang['help_anchor_location'] = '<strong>Note:</strong>&nbsp;Anchor locations specify the pixel location (relative to the top left corner of thie image) where the icon should be anchored to the marker.  If no value is specified, the center of the icon will be used';
$lang['help_icon_url'] = 'Specify the URL to the pre-uploaded PNG image.  This image should not be larger than 32x32, and should support transparency.  The URL can usually be specified relative to the root of your installation';
$lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page.';
$lang['help_param_map'] = 'Specify the ID or map name to use for laying out the google map.  If this parameter is not specified, the default map (if any) is used.';
$lang['help_param_maptemplate'] = 'Specify the name of an existing, non default map template to use for this output.  If this parameter is not specified, the current default map template will be used';
$lang['help_param_zoomlevel'] = '(integer) Allows overriding the zoom level stored with the map.  Valid values are from 1 to 17';
$lang['help_param_zoomencompass'] = '(boolean) Allows overriding the zoom encompass setting that is stored with the map.';
$lang['hide_directions'] = 'Skryť trasovanie';
$lang['horizontal_bar'] = 'Horizont&aacute;lna časť';
$lang['hybrid'] = 'Hybridna';
$lang['id'] = 'Idčko';
$lang['icon'] = 'Ikonka';
$lang['imperial'] = 'Cis&aacute;rska';
$lang['info'] = 'Inform&aacute;cia';
$lang['info_address_latlong'] = 'Note: Enter <strong>either</strong> an address <strong>or</strong> a lattitude and longitude.  If both the address and latitude and longitude are specified, latitude and longitude will be given preference.';
$lang['info_anchor_x'] = 'Informačn&eacute; okno po X lok&aacute;cii';
$lang['info_anchor_y'] = 'Inform&aacute;čn&eacute; okno po Y lok&aacute;cii';
$lang['info_bounds_fudge'] = 'When zoom encompass is specified you can specify a percentage <em>(in decimal)</em> by which to expand the map bounds to provide a &quot;margin&quot; around the encompassed points';
$lang['info_category_panel'] = 'Should a panel be displayed that shows the categories of all of the map points, and allow toggling map markers on and off by category';
$lang['info_center_lat'] = 'The Center latitude is optional.  If specified it will be used for centering the map.  Specify a value in decimal degrees i.e: -123.45';
$lang['info_center_lon'] = 'The Center longitude is optional.  If specified it will be used for centering the map. Specify a value in decimal degrees i.e: -123.45';
$lang['info_combine_points'] = 'If selected, points that are within a specified radius of each other will be combined into one marker on the map.  This functionality is useful if multiple entries exist at the same (or almost the same) coordinates, to ease in selection.  This functionality is independant of the map zoom level.';
$lang['info_controls'] = 'Should zoom and pan controls be displayed?';
$lang['info_controls_size'] = 'Specify the size of the controls on the map';
$lang['info_default_icon'] = 'The default icon is used when no other icon is specified for a map point';
$lang['info_directions'] = 'Allow the user to request directions from, or to a map point';
$lang['info_directions_dest'] = 'Specify how directions should be handled.  Should they be displayed in a new window, or in the map panel';
$lang['info_directions_units'] = 'Specify how the units should be displayed for directions.  Metric, or imperial.';
$lang['info_height'] = 'Specify a map height (in pixels)';
$lang['info_icon_selection'] = 'By default, which icon should be preferred for markers when the category panel is displayed';
$lang['info_info_trigger'] = 'Specify what should trigger the opening of the info window';
$lang['info_info_window'] = 'Should an information window be displayed for each map point?';
$lang['info_infowindow_height'] = 'Specify a height (in pixels) for the info window';
$lang['info_infowindow_width'] = 'Specify a width (in pixels) for the info window';
$lang['info_map_type'] = 'Specify the default map type (if type controls are enabled, the user can change the type after the map is displayed)';
$lang['info_nav_control_opt'] = 'Specify the type of navigation controls for the map';
$lang['info_point_combine_fudge'] = 'The smaller the radius means that fewer points will be combined into one map marker.  Negative values are invalid.';
$lang['info_point_combine_icon'] = 'Specify an icon to use to illustrate on the map that the marker consists of multiple points that are within a small area';
$lang['info_scalecontrols'] = 'A scale can optionally be displayed in the lower right corner of the map';
$lang['info_sensor'] = 'Niektor&eacute; prehliadače (hlavne mobiln&eacute;) s&uacute; umožnuj&uacute; z&iacute;skavať s&uacute;radnicov&eacute; (latitude a longitude). Chcete t&uacute;to voľu zapn&uacute;ť';
$lang['info_sidebar'] = 'Bočn&yacute; stĺpec bude obsahovať v&scaron;etky body na mape?';
$lang['info_sv_controls'] = 'Zobraziť ovl&aacute;dacie prvky StreetView  na mape?';
$lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street.';
$lang['info_sysdflt_baloon_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na pre pl&aacute;vaj&uacute;ce okno';
$lang['info_sysdflt_category_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na pre zoznam kateg&oacute;rii';
$lang['info_sysdflt_dirform_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na trasovania';
$lang['info_sysdflt_js_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na javascriptu';
$lang['info_sysdflt_map_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na mapy';
$lang['info_sysdflt_sidebar_template'] = 'Prednastaven&aacute; mapa bočn&eacute; stĺpca';
$lang['info_sysdflt_template'] = 'This form provides the ability to specify the content that will be displayed when you create a new template of this type.  Editing the content in this form will have no immediate effect on your website';
$lang['info_type_control_opt'] = 'Nastavenie ako sa bud&uacute; zobrazovať ovl&aacute;dacie prvky typu mapy';
$lang['info_width'] = '&Scaron;&iacute;rka mapy (px)';
$lang['infowindow_width'] = '&Scaron;&iacute;rka info okna';
$lang['infowindow_height'] = 'V&yacute;&scaron;ka info okna';
$lang['info_type_controls'] = 'Povoliť už&iacute;vateľovi zmeniť typ mapy?';
$lang['info_zoom'] = 'Konkretizuje nač&iacute;tavacie približovanie  (pozn&aacute;mka, tento parameter je ignorovan&yacute; v pr&iacute;pade zapnut&eacute;ho &quot;zoom encompass&quot;';
$lang['info_zoom_encompass'] = 'Zahrn&uacute;ť v&scaron;etky body do &uacute;rovňe prilb&iacute;ženia';
$lang['js_template'] = '&Scaron;abl&oacute;na z javascriptom';
$lang['large'] = 'Veľka';
$lang['latitude'] = 'Latitude';
$lang['latlong'] = 'Latitude / Longitude';
$lang['location'] = 'Umiestnenie';
$lang['longitude'] = 'Longitude';
$lang['make_default'] = 'Nastaviť ikonku ako prednastaven&uacute;';
$lang['marker_categories'] = 'Kateg&oacute;rie značiek';
$lang['marker_icons'] = 'Ikonky značky';
$lang['marker_skipped'] = 'Geolok&aacute;cia (adresa pre lat/long) chybn&aacute;.. značka &quot;%s&quot; preskočen&aacute;';
$lang['map'] = 'Mapa';
$lang['maps'] = 'Mapy';
$lang['maptemplate_addedit'] = 'Pridať/Upraviť &scaron;abl&oacute;nu mapy';
$lang['map_name'] = 'N&aacute;zov mapy';
$lang['map_template'] = '&Scaron;abl&oacute;na mapy';
$lang['map_templates'] = '&Scaron;abl&oacute;ny mapy';
$lang['map_type'] = 'Typ mapy';
$lang['metric'] = 'Metrick&yacute;';
$lang['moddescription'] = 'Jednoduch&yacute; modul pre vytv&aacute;ranie google m&aacute;';
$lang['mouseover'] = 'My&scaron;ou nad';
$lang['msg_categoryadded'] = 'Kateg&oacute;ria pridan&aacute;';
$lang['msg_categorydeleted'] = 'Kateg&oacute;ria  odstr&aacute;nen&aacute;';
$lang['msg_categoryupdated'] = 'Kateg&oacute;ria upraven&aacute;';
$lang['msg_default_icon_uchanged'] = 'Prednastaven&aacute; ikonka zmenen&aacute;';
$lang['msg_icons_reset'] = 'Ikonky boli prednastaven&eacute; do prednastaven&yacute;ch nastaven&iacute;';
$lang['msg_icon_removed'] = 'Ikonka odstr&aacute;nen&aacute; z DB, s&uacute;bor ostal fyzicky na serveri';
$lang['msg_icon_updated'] = 'Ikonka inform&aacute;cii zmenen&aacute;';
$lang['name'] = 'N&aacute;zov';
$lang['nav_control_opt'] = 'Veľkosť navigačnej li&scaron;ty';
$lang['none'] = 'Žiadne';
$lang['panel'] = 'Panel ';
$lang['points'] = 'Body';
$lang['point_combine_fudge'] = 'Zadajte r&aacute;dius ktor&yacute; &scaron;pecifikuje, ktor&eacute; body bud&uacute; kombinovan&eacute;';
$lang['point_combine_icon'] = 'Kombinovan&eacute; ikonky bodov';
$lang['point_name'] = 'N&aacute;zov bodu';
$lang['point_type'] = 'Typ bodu';
$lang['policy_cachefirst'] = 'Nač&iacute;tať ke&scaron; pred t&yacute;m ako sa zobraz&iacute; online inform&aacute;cia';
$lang['policy_cacheonly'] = 'Vždy použiť ke&scaron;';
$lang['policy_nocache'] = 'Nepouž&iacute;vať ke&scaron;';
$lang['postinstall'] = 'CGGoogleMaps modu bol nain&scaron;talovan&yacute;';
$lang['postuninstall'] = 'CGGoogleMaps modul a jeho d&aacute;ta boli odstr&aacute;nen&eacute;';
$lang['preferences'] = 'Nastavenia';
$lang['prompt_bounds_fudge'] = 'Zoom Encompass Bounds Fudge';
$lang['prompt_categories'] = 'Kateg&oacute;rie';
$lang['prompt_directions'] = 'Trasovanie';
$lang['prompt_from_here'] = 'Z miesta';
$lang['prompt_icon_selection'] = 'V&yacute;ber ikonky';
$lang['prompt_info_window'] = 'Okno z inform&aacute;ciami';
$lang['prompt_info_trigger'] = 'Udalosť vyvolania okna';
$lang['prompt_lookup_policy'] = 'Pravidl&aacute;';
$lang['prompt_lookup_service'] = 'Servis';
$lang['prompt_to_here'] = 'Do miesta ';
$lang['prompt_sensor'] = 'Supply Geographic location information to the map';
$lang['prompt_zoom'] = 'Level zoomovanie';
$lang['really_uninstall'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť tento modul';
$lang['reset'] = 'Resetn&uacute;ť';
$lang['reset_icons'] = 'Resent&uacute;ť ikonky';
$lang['satellite'] = 'Satelitn&eacute;';
$lang['scalecontrols'] = 'Zobraziť mierku';
$lang['set_dflt_map'] = 'Nastaviť mapu ako prednastaven&uacute;';
$lang['show_category_panel'] = 'Zobraziť panel kateg&oacute;rie';
$lang['sidebar'] = 'Zobraziť bočn&yacute; panel';
$lang['sidebar_template'] = '&Scaron;abl&oacute;na bočn&eacute;ho panelu';
$lang['small'] = 'Mal&eacute;';
$lang['submit'] = 'Odoslať';
$lang['sv_controls'] = 'Zobraziť ovl&aacute;dacie prvky Streetview';
$lang['sv_radius'] = 'Vyhľad&aacute;vac&iacute; r&aacute;dius Streetview';
$lang['tab_advanced'] = 'Roz&scaron;&iacute;ren&eacute;';
$lang['tab_directions'] = 'Smerovanie';
$lang['tab_jstemplate'] = '&Scaron;abl&oacute;na javascriptu';
$lang['tab_settings'] = 'Nastavenia';
$lang['tab_maptemplate'] = '&Scaron;abl&oacute;na mapy';
$lang['text'] = 'Text';
$lang['to'] = 'Do miesta';
$lang['type'] = 'Typ';
$lang['type_controls'] = 'Uk&aacute;zať navig&aacute;ciu';
$lang['type_control_opt'] = 'Ovl&aacute;dacie prvky';
$lang['url'] = 'URL adresa';
$lang['use_category_icon'] = 'Prednastaven&aacute; ikonka kateg&oacute;rie';
$lang['use_marker_icon'] = 'Prednastaven&aacute; ikonka značky';
$lang['width'] = 'Dĺžka';
$lang['window'] = 'Okno';
$lang['zoom_encompass'] = 'Zoom Encompass';
$lang['utma'] = '156861353.1685542931.1302729339.1303408317.1303506677.10';
$lang['utmz'] = '156861353.1303408317.9.8.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['qca'] = 'P0-455094516-1302813066046';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>